/**
 * Release project
 * @function release
 * @param {string} [dirname=process.cwd()] - Project directory name
 * @param {Object} [options={}] - Optional settings
 * @returns {Promise}
 */
'use strict'

const argx = require('argx')
const execcli = require('execcli')
const { releasePackage } = require('ape-releasing')

/** @lends release */
async function release (dirname = process.cwd(), options = {}) {
  let args = argx(arguments)
  options = args.pop('object') || {}
  dirname = args.shift('string') || process.cwd()
  let {
    beforeRelease = [
      () => execcli('git', ['add', '.']),
      () => execcli('git', ['commit', '--allow-empty', '-m', 'Releasing new package']),
      () => execcli('npm', ['run', 'build']),
      () => execcli('npm', ['run', 'test'])
    ],
    yes = false
  } = options
  try {
    let cwd = process.cwd()
    process.chdir(dirname)

    await releasePackage({
      beforeRelease,
      skipInteractive: yes
    })

    process.chdir(cwd)

    process.exit(0)
  } catch (err) {
    console.error(err)
    process.exit(1)
  }
}

module.exports = release
